@@ -979,7 +979,7 @@ class FourierSpectrum(Spectrum):
         s.plot(label='correlogram')
         from pylab import legend, xlim
         legend()
-        xlim(-512, 1024)
+        xlim(0,512)
 
     """
     _window = window_names
