@@ -1,6 +1,4 @@
 from spectrum import *
-from spectrum import modcovar 
-from modcovar import *
 import pylab
 from numpy.testing import *
 
