@@ -1,6 +1,4 @@
 from spectrum import *
-from spectrum import periodogram
-from periodogram import *
 
 from pylab import linspace, log10, plot, ylim, savefig
 from nose.tools import assert_almost_equal
